@@ -348,7 +348,7 @@ do_curl_duphandle(CurlObject *self)
     }
 
     /* Checking for CURLE_OK is not required here.
-     * All values have already been successfuly setopt'ed with self->handle. */
+     * All values have already been successfully setopt'ed with self->handle. */
 
     /* Assign and incref python callback and update data pointers */
     if (self->w_cb != NULL) {
@@ -606,13 +606,13 @@ PYCURL_INTERNAL void
 do_curl_dealloc(CurlObject *self)
 {
     PyObject_GC_UnTrack(self);
-    Py_TRASHCAN_SAFE_BEGIN(self);
+    CPy_TRASHCAN_BEGIN(self, do_curl_dealloc);
 
     Py_CLEAR(self->dict);
     util_curl_close(self);
 
     Curl_Type.tp_free(self);
-    Py_TRASHCAN_SAFE_END(self);
+    CPy_TRASHCAN_END(self);
 }
 
 
