@@ -13,7 +13,7 @@ setup_module, teardown_module = appmanager.setup(('app', 8384, dict(ssl=True)))
 
 class CaCertsTest(unittest.TestCase):
     def setUp(self):
-        self.curl = util.DefaultCurl()
+        self.curl = util.DefaultCurlLocalhost(8384)
 
     def tearDown(self):
         self.curl.close()
@@ -30,3 +30,14 @@ class CaCertsTest(unittest.TestCase):
         self.curl.setopt(pycurl.SSL_VERIFYPEER, 1)
         self.curl.perform()
         assert sio.getvalue().decode() == 'success'
+
+    @util.only_ssl_backends('openssl')
+    def test_set_ca_certs_bytes(self):
+        self.curl.set_ca_certs(util.b('hello world\x02\xe0'))
+
+    @util.only_ssl_backends('openssl')
+    def test_set_ca_certs_bogus_type(self):
+        try:
+            self.curl.set_ca_certs(42)
+        except TypeError as e:
+            self.assertEqual('set_ca_certs argument must be a byte string or a Unicode string with ASCII code points only', str(e))
