@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 # vi:ts=4:et
 
+from . import localhost
 import pycurl
 import unittest
 
@@ -14,7 +15,7 @@ class ResetTest(unittest.TestCase):
     def test_reset(self):
         c = util.DefaultCurl()
         c.setopt(pycurl.USERAGENT, 'Phony/42')
-        c.setopt(pycurl.URL, 'http://localhost:8380/header?h=user-agent')
+        c.setopt(pycurl.URL, 'http://%s:8380/header?h=user-agent' % localhost)
         sio = util.BytesIO()
         c.setopt(pycurl.WRITEFUNCTION, sio.write)
         c.perform()
@@ -22,7 +23,7 @@ class ResetTest(unittest.TestCase):
         assert user_agent == 'Phony/42'
 
         c.reset()
-        c.setopt(pycurl.URL, 'http://localhost:8380/header?h=user-agent')
+        c.setopt(pycurl.URL, 'http://%s:8380/header?h=user-agent' % localhost)
         sio = util.BytesIO()
         c.setopt(pycurl.WRITEFUNCTION, sio.write)
         c.perform()
@@ -40,7 +41,7 @@ class ResetTest(unittest.TestCase):
 
         for x in range(1, 20):
             eh.setopt(pycurl.WRITEFUNCTION, outf.write)
-            eh.setopt(pycurl.URL, 'http://localhost:8380/success')
+            eh.setopt(pycurl.URL, 'http://%s:8380/success' % localhost)
             cm.add_handle(eh)
 
             while 1:
