@@ -3,8 +3,9 @@
 # vi:ts=4:et
 
 import pycurl
+import pytest
+from . import localhost
 import unittest
-import nose.tools
 
 from . import appmanager
 from . import util
@@ -19,12 +20,12 @@ class SetoptTest(unittest.TestCase):
         self.curl.close()
 
     def test_setopt_string(self):
-        self.curl.setopt_string(pycurl.URL, 'http://localhost:8380/success')
+        self.curl.setopt_string(pycurl.URL, 'http://%s:8380/success' % localhost)
         sio = util.BytesIO()
         self.curl.setopt(pycurl.WRITEFUNCTION, sio.write)
         self.curl.perform()
         self.assertEqual('success', sio.getvalue().decode())
 
-    @nose.tools.raises(TypeError)
     def test_setopt_string_integer(self):
-        self.curl.setopt_string(pycurl.VERBOSE, True)
+        with pytest.raises(TypeError):
+            self.curl.setopt_string(pycurl.VERBOSE, True)
